@@ -4,10 +4,9 @@ import tkinter as tk
 from tkinter import ttk
 from tkinter import filedialog
 from tkinter import messagebox
+from tkinter.font import Font
 
-from os import path
 import webbrowser
-from textwrap import dedent
 from textwrap import indent
 import re
 import platform
@@ -23,6 +22,7 @@ from dlapp.collection import Tabular
 from templateapp import TemplateBuilder
 from templateapp.exceptions import TemplateBuilderInvalidFormat
 from templateapp.core import save_file
+from templateapp.config import Data
 
 from templateapp import version
 from templateapp import edition
@@ -119,51 +119,6 @@ def set_modal_dialog(dialog):
     dialog.wait_window()
 
 
-class Data:
-    license_name = 'BSD 3-Clause License'
-    repo_url = 'https://github.com/Geeks-Trident-LLC/templateapp'
-    license_url = path.join(repo_url, 'blob/main/LICENSE')
-    # TODO: Need to update wiki page for documentation_url instead of README.md.
-    documentation_url = path.join(repo_url, 'blob/develop/README.md')
-    copyright_text = 'Copyright @ 2021-2040 Geeks Trident LLC.  All rights reserved.'
-
-    @classmethod
-    def get_license(cls):
-        license_ = """
-            BSD 3-Clause License
-
-            Copyright (c) 2021-2040, Geeks Trident LLC
-            All rights reserved.
-
-            Redistribution and use in source and binary forms, with or without
-            modification, are permitted provided that the following conditions are met:
-
-            1. Redistributions of source code must retain the above copyright notice, this
-               list of conditions and the following disclaimer.
-
-            2. Redistributions in binary form must reproduce the above copyright notice,
-               this list of conditions and the following disclaimer in the documentation
-               and/or other materials provided with the distribution.
-
-            3. Neither the name of the copyright holder nor the names of its
-               contributors may be used to endorse or promote products derived from
-               this software without specific prior written permission.
-
-            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-            AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-            DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
-            FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-            DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
-            SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-            CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-            OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-            OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-        """
-        license_ = dedent(license_).strip()
-        return license_
-
-
 class Snapshot(dict):
     """Snapshot for storing data."""
     def __init__(self, *args, **kwargs):
@@ -622,6 +577,61 @@ class Application:
         stored_title = self.snapshot.stored_title or 'Storing Template'     # noqa
         self.set_title(title=stored_title)
 
+    def create_custom_label(self, parent, text='', link='',
+                            increased_size=0, bold=False, underline=False,
+                            italic=False):
+        """create custom label
+
+        Parameters
+        ----------
+        parent (tkinter): a parent of widget.
+        text (str): a text of widget.
+        link (str): a label hyperlink.
+        increased_size (int): a increased size for font.
+        bold (bool): True will set bold font.
+        underline (bool): True will set to underline font.
+        italic (bool): True will set to italic font.
+
+        Returns
+        -------
+        tkinter.Label: a label widget.
+        """
+
+        def mouse_over(event):
+            if 'underline' not in event.widget.font:
+                event.widget.configure(
+                    font=event.widget.font + ['underline'],
+                    cursor='hand2'
+                )
+
+        def mouse_out(event):
+            event.widget.config(
+                font=event.widget.font,
+                cursor='arrow'
+            )
+
+        def mouse_press(event):
+            self.browser.open_new_tab(event.widget.link)
+
+        style = ttk.Style()
+        style.configure("Blue.TLabel", foreground="blue")
+        if link:
+            label = self.Label(parent, text=text, style='Blue.TLabel')
+            label.bind('<Enter>', mouse_over)
+            label.bind('<Leave>', mouse_out)
+            label.bind('<Button-1>', mouse_press)
+        else:
+            label = self.Label(parent, text=text)
+        font = Font(name='TkDefaultFont', exists=True, root=label)
+        font = [font.cget('family'), font.cget('size') + increased_size]
+        bold and font.append('bold')
+        underline and font.append('underline')
+        italic and font.append('italic')
+        label.configure(font=font)
+        label.font = font
+        label.link = link
+        return label
+
     def callback_focus(self, event):
         """Callback for widget selection"""
         try:
@@ -648,7 +658,7 @@ class Application:
                 if self.search_chkbox_var.get():
                     self.search_chkbox.invoke()
 
-                if self.snapshot.curr_app == 'backup_app':
+                if self.snapshot.curr_app == 'backup_app':  # noqa
                     self.close_backup_btn.invoke()
 
                 content = stream.read()
@@ -675,7 +685,7 @@ class Application:
                 if self.search_chkbox_var.get():
                     self.search_chkbox.invoke()
 
-                if self.snapshot.curr_app == 'backup_app':
+                if self.snapshot.curr_app == 'backup_app':  # noqa
                     self.close_backup_btn.invoke()
 
                 content = stream.read()
@@ -714,21 +724,6 @@ class Application:
     def callback_help_about(self):
         """Callback for Menu Help > About"""
 
-        def mouse_over(event):
-            event.widget.config(
-                font=event.widget.default_font + ('underline',),
-                cursor='hand2'
-            )
-
-        def mouse_out(event):
-            event.widget.config(
-                font=event.widget.default_font,
-                cursor='arrow'
-            )
-
-        def mouse_press(event):
-            self.browser.open_new_tab(event.widget.link)
-
         about = tk.Toplevel(self.root)
         self.set_title(widget=about, title='About')
         width, height = 460, 460
@@ -746,13 +741,10 @@ class Application:
         frame = self.Frame(paned_window, width=450, height=20)
         paned_window.add(frame, weight=4)
 
-        font_size = 12 if self.is_macos else 10
-        fmt = 'TemplateApp v{} ({} Edition)'
-        company_lbl = self.Label(
-            frame, text=fmt.format(version, edition),
-            font=('san-serif', font_size, 'bold')
-        )
-        company_lbl.grid(row=0, column=0, columnspan=2, sticky=tk.W)
+        self.create_custom_label(
+            frame, text=Data.main_app_text,
+            increased_size=2, bold=True
+        ).grid(row=0, column=0, columnspan=2, sticky=tk.W)
 
         # URL
         cell_frame = self.Frame(frame, width=450, height=5)
@@ -760,80 +752,39 @@ class Application:
 
         url = Data.repo_url
         self.Label(cell_frame, text='URL:').pack(side=tk.LEFT)
-        style = ttk.Style()
-        style.configure("Blue.TLabel", foreground="blue")
-        label = self.Label(
-            cell_frame, text=url, font=('sans-serif', font_size),
-            style='Blue.TLabel'
-        )
-        label.default_font = ('sans-serif', font_size)
-        label.pack(side=tk.LEFT)
-        label.link = url
 
-        label.bind('<Enter>', mouse_over)
-        label.bind('<Leave>', mouse_out)
-        label.bind('<Button-1>', mouse_press)
+        self.create_custom_label(
+            cell_frame, text=url, link=url
+        ).pack(side=tk.LEFT)
 
         # dependencies
-        self.Label(
-            frame, text='Pypi.com Dependencies:',
-            font=('sans-serif', font_size, 'underline')
+        self.create_custom_label(
+            frame, text='Pypi.com Dependencies:', bold=True
         ).grid(row=2, column=0, sticky=tk.W)
 
-        # regexapp package
-        import regexapp as rapp
-        text = 'RegexApp v{} ({} Edition)'.format(rapp.version, rapp.edition)
-        label = self.Label(
-            frame, text=text, font=('sans-serif', font_size),
-            style='Blue.TLabel'
-        )
-        label.default_font = ('sans-serif', font_size)
-        label.grid(row=3, column=0, padx=(20, 0), sticky=tk.W)
-        label.link = 'https://pypi.org/project/regexapp/'
-        label.bind('<Enter>', mouse_over)
-        label.bind('<Leave>', mouse_out)
-        label.bind('<Button-1>', mouse_press)
+        # RegexApp package
+        self.create_custom_label(
+            frame, text=Data.regexapp_text,
+            link=Data.regexapp_link
+        ).grid(row=3, column=0, padx=(20, 0), sticky=tk.W)
 
-        # dlapp package
-        import dlapp
-        text = 'DLApp v{} ({} Edition)'.format(dlapp.version, dlapp.edition)
-        label = self.Label(
-            frame, text=text, font=('sans-serif', font_size),
-            style='Blue.TLabel'
-        )
-        label.default_font = ('sans-serif', font_size)
-        label.grid(row=4, column=0, padx=(20, 0), pady=(0, 10), sticky=tk.W)
-        label.link = 'https://pypi.org/project/dlapp/'
-        label.bind('<Enter>', mouse_over)
-        label.bind('<Leave>', mouse_out)
-        label.bind('<Button-1>', mouse_press)
+        # DLApp package
+        self.create_custom_label(
+            frame, text=Data.dlapp_text,
+            link=Data.dlapp_link
+        ).grid(row=4, column=0, padx=(20, 0), pady=(0, 10), sticky=tk.W)
 
-        # textfsm package
-        import textfsm
-        text = 'TextFSM v{}'.format(textfsm.__version__)
-        label = self.Label(
-            frame, text=text, font=('sans-serif', font_size),
-            style='Blue.TLabel'
-        )
-        label.default_font = ('sans-serif', font_size)
-        label.grid(row=3, column=1, padx=(20, 0), sticky=tk.W)
-        label.link = 'https://pypi.org/project/textfsm/'
-        label.bind('<Enter>', mouse_over)
-        label.bind('<Leave>', mouse_out)
-        label.bind('<Button-1>', mouse_press)
+        # TextFSM package
+        self.create_custom_label(
+            frame, text=Data.textfsm_text,
+            link=Data.textfsm_link
+        ).grid(row=3, column=1, padx=(20, 0), sticky=tk.W)
 
         # PyYAML package
-        text = 'PyYAML v{}'.format(yaml.__version__)
-        label = self.Label(
-            frame, text=text, font=('sans-serif', font_size),
-            style='Blue.TLabel'
-        )
-        label.default_font = ('sans-serif', font_size)
-        label.grid(row=4, column=1, padx=(20, 0), pady=(0, 10), sticky=tk.W)
-        label.link = 'https://pypi.org/project/PyYAML/'
-        label.bind('<Enter>', mouse_over)
-        label.bind('<Leave>', mouse_out)
-        label.bind('<Button-1>', mouse_press)
+        self.create_custom_label(
+            frame, text=Data.pyyaml_text,
+            link=Data.pyyaml_link
+        ).grid(row=4, column=1, padx=(20, 0), pady=(0, 10), sticky=tk.W)
 
         # license textbox
         lframe = self.LabelFrame(
@@ -849,15 +800,20 @@ class Application:
         scrollbar = ttk.Scrollbar(lframe, orient=tk.VERTICAL, command=txtbox.yview)
         scrollbar.grid(row=0, column=1, sticky='nsew')
         txtbox.config(yscrollcommand=scrollbar.set)
-        txtbox.insert(tk.INSERT, Data.get_license())
+        txtbox.insert(tk.INSERT, Data.license)
         txtbox.config(state=tk.DISABLED)
 
         # footer - copyright
         frame = self.Frame(paned_window, width=450, height=20)
         paned_window.add(frame, weight=1)
 
-        footer = self.Label(frame, text=Data.copyright_text)
-        footer.pack(side=tk.LEFT, pady=(10, 10))
+        self.Label(frame, text=Data.copyright_text).pack(side=tk.LEFT, pady=(10, 10))
+
+        self.create_custom_label(
+            frame, text=Data.company, link=Data.company_url
+        ).pack(side=tk.LEFT, pady=(10, 10))
+
+        self.Label(frame, text='.  All right reserved.').pack(side=tk.LEFT, pady=(10, 10))
 
         set_modal_dialog(about)
 
@@ -1462,7 +1418,7 @@ class Application:
                 self.snapshot.update(is_built=True)
                 template = factory.template
             except Exception as ex:
-                template = self.snapshot.template.strip()
+                template = self.snapshot.template.strip()   # noqa
                 if not template:
                     error = '{}: {}'.format(type(ex).__name__, ex)
                     create_msgbox(title='RegexBuilder Error', error=error)
