@@ -9,5 +9,9 @@ class TemplateParsedLineError(TemplateError):
     """Use to capture error parsed line for template builder."""
 
 
-class TemplateBuilderError(Exception):
+class TemplateBuilderError(TemplateError):
     """Use to capture error template construction."""
+
+
+class TemplateBuilderInvalidFormat(TemplateError):
+    """Use to capture error if user_data has invalid format."""
